package com.app.linkv.example.view;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.ShapeDrawable;
import android.util.AttributeSet;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.widget.FrameLayout;
import android.widget.TextView;

import com.app.common.common.DimenUtils;
import com.app.linkv.example.R;
import com.app.view.RoundRectShape;

public final class RegisterBottomButton extends FrameLayout {

    private TextView mBtnTv;

    private Drawable mBgEnabled;
    private Drawable mBgDisabled;

    public RegisterBottomButton(Context context) {
        this(context, null);
    }

    public RegisterBottomButton(Context context, AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public RegisterBottomButton(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        LayoutInflater.from(context).inflate(
                R.layout.register_btm_btn_layout, this);

        initView();
        update(isEnabled());
    }

    @Override
    public void setEnabled(boolean enabled) {
        super.setEnabled(enabled);
        update(isEnabled());
    }

    public void setBtnText(int resid) {
        mBtnTv.setText(resid);
    }

    public void setBtnText(CharSequence text) {
        mBtnTv.setText(text);
    }

    private void initView() {
        mBtnTv = (TextView) findViewById(R.id.btnTv);
        mBtnTv.setGravity(Gravity.CENTER);
    }

    private void update(boolean enabled) {
        mBtnTv.setBackgroundDrawable(getBgDrawable(enabled));
    }

    private Drawable getBgDrawable(boolean enabled) {
        if (enabled) {
            if (mBgEnabled == null) {
                final Context ctx = getContext();
                int color = ctx.getResources().getColor(R.color.common_color_button);
                mBgEnabled = new ShapeDrawable(new RoundRectShape(
                        0, color, color, DimenUtils.dp2px(ctx, 30.0f)));
            }
            return mBgEnabled;
        } else {
            if (mBgDisabled == null) {
                final Context ctx = getContext();
                int color = Color.parseColor("#ffD3D3D3");
                mBgDisabled = new ShapeDrawable(new RoundRectShape(
                        0, color, color, DimenUtils.dp2px(ctx, 30.0f)));
            }
            return mBgDisabled;
        }
    }

}
