package com.app.linkv.example.view;

import android.content.Context;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.AttrRes;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.app.linkv.example.R;


public class TitleLayout extends FrameLayout {

    private ImageView mBackImg;
    private TextView mRightTxt;

    private TitleClickListener mListener;

    public TitleLayout(@NonNull Context context) {
        super(context);
        initView(context);
    }

    public TitleLayout(@NonNull Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        initView(context);
    }

    public TitleLayout(@NonNull Context context, @Nullable AttributeSet attrs, @AttrRes int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        initView(context);
    }

    public void setTitleClickListener(TitleClickListener listener) {
        mListener = listener;
    }

    private void initView(Context ctx) {
        LayoutInflater.from(ctx).inflate(R.layout.layout_simple_title, this);
        mBackImg = (ImageView) findViewById(R.id.img_back);
        mBackImg.setVisibility(GONE);
        mBackImg.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mListener != null) {
                    mListener.onBackClicked();
                }
            }
        });
        mRightTxt = (TextView) findViewById(R.id.txt_right);
        mRightTxt.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mListener != null) {
                    mListener.onRightBtnClicked();
                }
            }
        });
    }

    public void setRightBtnText(String content) {
        mRightTxt.setText(content);
    }

    public void changeRightBtnVisibility(int visibility) {
        mRightTxt.setVisibility(visibility);
    }

    public void changeBackVisibility(int visibility) {
        mBackImg.setVisibility(visibility);
    }

    public interface TitleClickListener {
        void onBackClicked();

        void onRightBtnClicked();
    }
}
